@@ -1,6 +1,6 @@
 /*#define	DEBUG 1 */
 /*
- * $Id: rpcfilter.c,v 1.24 2008/12/11 14:46:50 c4chris Exp $
+ * $Id: rpcfilter.c,v 1.25 2010/04/22 15:56:22 c4chris Exp $
  */
 
 #include "os.h"
@@ -81,7 +81,7 @@
 #include <sys/sysmacros.h>
 #endif
 
-#ifdef __alpha
+#if defined(__alpha) && !defined(LINUX)
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/mount.h>
